@@ -1,6 +1,7 @@
-import sqlite3
 import atexit
 import logging
+import sqlite3
+import os
 
 
 class SQLHelper:
@@ -13,14 +14,15 @@ class SQLHelper:
         atexit.register(self.exit_handler)
 
     async def sql_initialize(self):
+        if os.path.exists("download_history_size_based.sqlite"):
+            os.remove("download_history_size_based.sqlite")
         self.conn = sqlite3.connect(self.download_history)
         self.curs = self.conn.cursor()
         create_table_query = """CREATE TABLE IF NOT EXISTS downloads (
-                                    filename TEXT,
+                                    path TEXT,
                                     downloaded_filename TEXT,
-                                    size INTEGER NOT NULL,
                                     completed INTEGER NOT NULL,
-                                    PRIMARY KEY (filename, size)
+                                    PRIMARY KEY (path)
                                 );"""
         self.curs.execute(create_table_query)
         self.conn.commit()
@@ -28,59 +30,48 @@ class SQLHelper:
 
     async def check_columns(self):
         self.curs.execute("""SELECT COUNT(*) AS CNTREC FROM pragma_table_info('downloads') WHERE 
-                             name='downloaded_filename'""")
+                             name='path'""")
         sql_check = self.curs.fetchone()[0]
         if sql_check == (0):
-            create_table_query = """CREATE TABLE IF NOT EXISTS downloads_temp (
-                                                filename TEXT,
-                                                downloaded_filename TEXT,
-                                                size INTEGER NOT NULL,
-                                                completed INTEGER NOT NULL,
-                                                PRIMARY KEY (filename, size)
-                                            );"""
+            self.curs.execute("""DROP TABLE downloads""")
+            self.conn.commit()
+            create_table_query = """CREATE TABLE IF NOT EXISTS downloads (
+                                    path TEXT,
+                                    downloaded_filename TEXT,
+                                    completed INTEGER NOT NULL,
+                                    PRIMARY KEY (path)
+                                );"""
             self.curs.execute(create_table_query)
             self.conn.commit()
-            self.curs.execute("""INSERT INTO downloads_temp SELECT filename, filename, size, completed from downloads""")
-            self.curs.execute("""DROP TABLE downloads""")
-            self.curs.execute("""ALTER TABLE downloads_temp RENAME TO downloads""")
-            self.conn.commit()
 
-    async def sql_check_existing(self, filename, size):
+    async def sql_check_existing(self, path):
         if self.ignore_history:
             return False
-        self.curs.execute("""SELECT completed FROM downloads WHERE filename = '%s' and size = %d""" % (filename, size))
+        self.curs.execute("""SELECT completed FROM downloads WHERE path = ?""", (path, ))
         sql_file_check = self.curs.fetchone()
         if sql_file_check:
             if sql_file_check[0] == 1:
                 return True
         return False
 
-    async def sql_insert_file(self, filename, downloaded_filename, size, completed):
-        self.curs.execute("""INSERT OR IGNORE INTO downloads VALUES ('%s', '%s', %d, %d)""" % (filename, downloaded_filename, size, completed))
+    async def sql_insert_file(self, path, downloaded_filename, completed):
+        self.curs.execute("""INSERT OR IGNORE INTO downloads VALUES (?, ?, ?)""", (path, downloaded_filename, completed, ))
         self.conn.commit()
 
-    async def sql_update_file(self, filename, downloaded_filename, size, completed):
-        self.curs.execute("""INSERT OR REPLACE INTO downloads VALUES ('%s', '%s', %d, %d)""" % (filename, downloaded_filename, size, completed))
+    async def sql_update_file(self, path, downloaded_filename, completed):
+        self.curs.execute("""INSERT OR REPLACE INTO downloads VALUES (?, ?, ?)""", (path, downloaded_filename, completed, ))
         self.conn.commit()
 
     async def check_filename(self, filename):
-        self.curs.execute("""SELECT EXISTS(SELECT 1 FROM downloads WHERE filename = '%s')""" % filename)
+        self.curs.execute("""SELECT EXISTS(SELECT 1 FROM downloads WHERE downloaded_filename = ?)""", (filename, ))
         sql_check = self.curs.fetchone()[0]
         if sql_check == 1:
             return True
         else:
             return False
 
-    async def check_filename_for_downloaded(self, filename):
-        self.curs.execute("""SELECT EXISTS(SELECT 1 FROM downloads WHERE downloaded_filename = '%s')""" % (filename))
-        sql_check = self.curs.fetchone()[0]
-        if sql_check == 1:
-            return True
-        else:
-            return False
-
-    async def get_download_filename(self, filename, size):
-        self.curs.execute("""SELECT downloaded_filename FROM downloads WHERE filename = '%s' and size = %d""" % (filename, size))
+    async def get_download_filename(self, path):
+        self.curs.execute("""SELECT downloaded_filename FROM downloads WHERE path = ?""", (path, ))
         filename = self.curs.fetchone()
         if filename:
             return filename[0]
@@ -95,4 +86,3 @@ class SQLHelper:
             logging.debug(f"Failed to close sqlite database connection: {str(e)}")
         else:
             logging.debug("Successfully closed sqlite database connection")
-        
\ No newline at end of file
